=== modified file 'drizzled/foreign_key.cc'
--- drizzled/foreign_key.cc	2010-02-04 08:14:46 +0000
+++ drizzled/foreign_key.cc	2010-07-26 18:50:01 +0000
@@ -25,12 +25,48 @@
 #include "drizzled/error.h"
 #include "drizzled/create_field.h"
 #include "drizzled/internal/my_sys.h"
+#include "drizzled/table_ident.h"
 
 namespace drizzled
 {
 
 extern const CHARSET_INFO *system_charset_info;
 
+void add_foreign_key_to_table_message(
+    message::Table *table_message,
+    const char* fkey_name,
+    List<Key_part_spec> &cols,
+    Table_ident *table,
+    List<Key_part_spec> &ref_cols,
+    message::Table::ForeignKeyConstraint::ForeignKeyOption delete_opt_arg,
+    message::Table::ForeignKeyConstraint::ForeignKeyOption update_opt_arg,
+    message::Table::ForeignKeyConstraint::ForeignKeyMatchOption match_opt_arg)
+{
+  message::Table::ForeignKeyConstraint *pfkey= table_message->add_fk_constraint();
+  if (fkey_name)
+    pfkey->set_name(fkey_name);
+
+  pfkey->set_match(match_opt_arg);
+  pfkey->set_update_option(update_opt_arg);
+  pfkey->set_delete_option(delete_opt_arg);
+
+  pfkey->set_references_table_name(table->table.str);
+
+  Key_part_spec *keypart;
+  List_iterator<Key_part_spec> col_it(cols);
+  while ((keypart= col_it++))
+  {
+    pfkey->add_column_names(keypart->field_name.str);
+  }
+
+  List_iterator<Key_part_spec> ref_it(ref_cols);
+  while ((keypart= ref_it++))
+  {
+    pfkey->add_references_columns(keypart->field_name.str);
+  }
+
+}
+
 Foreign_key::Foreign_key(const Foreign_key &rhs, memory::Root *mem_root)
   :Key(rhs),
   ref_table(rhs.ref_table),

=== modified file 'drizzled/foreign_key.h'
--- drizzled/foreign_key.h	2010-07-13 01:12:39 +0000
+++ drizzled/foreign_key.h	2010-07-26 18:50:01 +0000
@@ -36,6 +36,17 @@
 
 namespace memory { class Root; }
 
+void add_foreign_key_to_table_message(
+    message::Table *table_message,
+    const char* fkey_name,
+    List<Key_part_spec> &cols,
+    Table_ident *table,
+    List<Key_part_spec> &ref_cols,
+    message::Table::ForeignKeyConstraint::ForeignKeyOption delete_opt_arg,
+    message::Table::ForeignKeyConstraint::ForeignKeyOption update_opt_arg,
+    message::Table::ForeignKeyConstraint::ForeignKeyMatchOption match_opt_arg);
+
+
 class Foreign_key: public Key 
 {
 public:

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-07-20 16:36:03 +0000
+++ drizzled/sql_table.cc	2010-07-26 18:50:01 +0000
@@ -889,29 +889,6 @@
 	return(true);
       }
 
-      message::Table::ForeignKeyConstraint *pfkey= create_proto.add_fk_constraint();
-      if (fk_key->name.str)
-        pfkey->set_name(fk_key->name.str);
-
-      pfkey->set_match(fk_key->match_opt);
-      pfkey->set_update_option(fk_key->update_opt);
-      pfkey->set_delete_option(fk_key->delete_opt);
-
-      pfkey->set_references_table_name(fk_key->ref_table->table.str);
-
-      Key_part_spec *keypart;
-      List_iterator<Key_part_spec> col_it(fk_key->columns);
-      while ((keypart= col_it++))
-      {
-        pfkey->add_column_names(keypart->field_name.str);
-      }
-
-      List_iterator<Key_part_spec> ref_it(fk_key->ref_columns);
-      while ((keypart= ref_it++))
-      {
-        pfkey->add_references_columns(keypart->field_name.str);
-      }
-
       continue;
     }
     (*key_count)++;

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-07-13 07:12:12 +0000
+++ drizzled/sql_yacc.yy	2010-07-26 18:50:01 +0000
@@ -1401,6 +1401,16 @@
                                       statement->fk_delete_opt,
                                       statement->fk_update_opt,
                                       statement->fk_match_option);
+
+	    add_foreign_key_to_table_message(&(statement->create_table_message),
+                                             $4.str ? $4.str : $1.str,
+                                             lex->col_list,
+                                             $8,
+                                             lex->ref_list,
+                                             statement->fk_delete_opt,
+                                             statement->fk_update_opt,
+                                             statement->fk_match_option);
+
             statement->alter_info.key_list.push_back(key);
             key= new Key(Key::MULTIPLE, $1.str ? $1 : $4,
                          &default_key_create_info, 1,

